==> ws-v3.80.1-src.tar.gz: ws-v3.80-1/include/WSChorzForm.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCHORZFORM_H
#define WSCHORZFORM_H

#include <WScom.h>
#include <WSCvertForm.h>

#define WSChorzForm_VER  1001

class WSChorzForm   :public WSCvertForm{

  protected:
    WSMFpropertyDef(WSNalignmentV,  WSCuchar, _alignment);
    virtual void  _exec_child_adjust_for_anchors();

  public:
    WSChorzForm(WSCbase*,char*);
    virtual ~WSChorzForm();


    WSMFguiClassDef(WSChorzForm,WSCvertForm);
    WSMFversionDef(WSChorzForm);
};
#endif

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/WSChorzForm.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSCHORZFORM_H
#define WSCHORZFORM_H

#include <WScom.h>
#include <WSCvertForm.h>

#define WSChorzForm_VER  1001

class WSChorzForm   :public WSCvertForm{

  protected:
    WSMFpropertyDef(WSNalignmentV,  WSCuchar, _alignment);
    WSDLEX32 virtual void  _exec_child_adjust_for_anchors();

  public:
    WSDLEX32 WSChorzForm(WSCbase*,char*);
    WSDLEX32 virtual ~WSChorzForm();


    WSMFguiClassDef(WSChorzForm,WSCvertForm);
    WSMFversionDef(WSChorzForm);
};
#endif
